@@ -4,7 +4,10 @@ import traceback
 import typing as ty
 import warnings
 
-import click
+try:
+    import asyncclick as click
+except ImportError:
+    import click
 from docutils import nodes
 from docutils.parsers import rst
 from docutils.parsers.rst import directives
